@@ -1,6 +1,8 @@
 import logging
+from datetime import timedelta
 from sqlalchemy import and_
 from sqlalchemy.exc import IntegrityError
+from sqlalchemy.orm.exc import ObjectDeletedError
 
 from vwsfriend.model.charge import Charge
 from vwsfriend.model.charging_session import ChargingSession, ACDC
@@ -62,7 +64,7 @@ class ChargeAgent():
                                                                                                           AddressableLeaf.ObserverEvent.VALUE_CHANGED,
                                                                                                           onUpdateComplete=True)
 
-    def __onChargingStatusCarCapturedTimestampChange(self, element, flags):
+    def __onChargingStatusCarCapturedTimestampChange(self, element, flags):  # noqa: C901
         if element is not None and element.value is not None:
             chargeStatus = self.vehicle.weConnectVehicle.domains['charging']['chargingStatus']
             current_remainingChargingTimeToComplete_min = None
@@ -81,6 +83,14 @@ class ChargeAgent():
             if chargeStatus.chargeRate_kmph.enabled:
                 current_chargeRate_kmph = chargeStatus.chargeRate_kmph.value
 
+            if self.charge is not None:
+                try:
+                    self.session.refresh(self.charge)
+                except ObjectDeletedError:
+                    LOG.warning('Last charge entry was deleted')
+                    self.charge = self.session.query(Charge).filter(and_(Charge.vehicle == self.vehicle, Charge.carCapturedTimestamp.isnot(None))) \
+                        .order_by(Charge.carCapturedTimestamp.desc()).first()
+
             if self.charge is None or (self.charge.carCapturedTimestamp != chargeStatus.carCapturedTimestamp.value and (
                     self.charge.remainingChargingTimeToComplete_min != current_remainingChargingTimeToComplete_min
                     or self.charge.chargingState != current_chargingState
@@ -95,20 +105,41 @@ class ChargeAgent():
                         self.session.add(self.charge)
                     self.session.commit()
                 except IntegrityError as err:
-                    LOG.warning('Could not add charging session entry to the database, this is usually due to an error in the WeConnect API (%s)', err)
+                    LOG.warning('Could not add charge entry to the database, this is usually due to an error in the WeConnect API (%s)', err)
 
     def __onChargingStateChange(self, element, flags):  # noqa: C901
         chargeStatus = self.vehicle.weConnectVehicle.domains['charging']['chargingStatus']
-        if element.value == ChargingStatus.ChargingState.CHARGING:
+
+        if self.chargingSession is not None:
+            try:
+                self.session.refresh(self.chargingSession)
+            except ObjectDeletedError:
+                LOG.warning('Open charging session was deleted')
+                self.previousChargingSession = None
+                chargingSession = self.session.query(ChargingSession).filter(ChargingSession.vehicle == self.vehicle) \
+                    .order_by(ChargingSession.started.desc()).first()
+                if chargingSession is not None and not chargingSession.isClosed():
+                    self.chargingSession = chargingSession
+                else:
+                    self.chargingSession = None
+
+        if element.value in [ChargingStatus.ChargingState.CHARGING, ChargingStatus.ChargingState.CHARGE_PURPOSE_REACHED_CONSERVATION,
+                             ChargingStatus.ChargingState.CONSERVATION]:
             if self.chargingSession is None or self.chargingSession.isClosed():
-                self.previousChargingSession = self.chargingSession
-                self.chargingSession = ChargingSession(vehicle=self.vehicle)
-                try:
-                    with self.session.begin_nested():
-                        self.session.add(self.chargingSession)
-                    self.session.commit()
-                except IntegrityError:
-                    LOG.warning('Could not add charging session entry to the database, this is usually due to an error in the WeConnect API')
+                # In case this was an interrupted charging session (interrupt no longer than 24hours), continue by erasing end time
+                if self.chargingSession is not None and not self.chargingSession.wasDisconnected() \
+                        and self.chargingSession.ended > (chargeStatus.carCapturedTimestamp.value - timedelta(hours=24)):
+                    self.chargingSession.ended = None
+                    self.chargingSession.endSOC_pct = None
+                else:
+                    self.previousChargingSession = self.chargingSession
+                    self.chargingSession = ChargingSession(vehicle=self.vehicle)
+                    try:
+                        with self.session.begin_nested():
+                            self.session.add(self.chargingSession)
+                        self.session.commit()
+                    except IntegrityError:
+                        LOG.warning('Could not add charging session entry to the database, this is usually due to an error in the WeConnect API')
             if not self.chargingSession.wasStarted():
                 self.chargingSession.started = chargeStatus.carCapturedTimestamp.value
             # also write start SoC
@@ -120,9 +151,9 @@ class ChargeAgent():
             # also write start charge type if available and not already set
             if self.chargingSession is not None and self.chargingSession.acdc is None \
                     and chargeStatus.chargeType.enabled:
-                if chargeStatus.chargeType == ChargingStatus.ChargeType.AC:
+                if chargeStatus.chargeType.value == ChargingStatus.ChargeType.AC:
                     self.chargingSession.acdc = ACDC.AC
-                elif chargeStatus.chargeType == ChargingStatus.ChargeType.DC:
+                elif chargeStatus.chargeType.value == ChargingStatus.ChargeType.DC:
                     self.chargingSession.acdc = ACDC.DC
 
             # also write position if available
@@ -130,7 +161,12 @@ class ChargeAgent():
 
             # also write milage if available
             self.updateMileage()
-        elif element.value in [ChargingStatus.ChargingState.OFF, ChargingStatus.ChargingState.READY_FOR_CHARGING]:
+
+            self.session.commit()
+        elif element.value in [ChargingStatus.ChargingState.OFF, ChargingStatus.ChargingState.READY_FOR_CHARGING,
+                               ChargingStatus.ChargingState.NOT_READY_FOR_CHARGING,
+                               ChargingStatus.ChargingState.CHARGE_PURPOSE_REACHED_NOT_CONSERVATION_CHARGING,
+                               ChargingStatus.ChargingState.ERROR]:
             if self.chargingSession is not None and self.chargingSession.isChargingState():
                 self.chargingSession.ended = chargeStatus.carCapturedTimestamp.value
 
@@ -153,8 +189,24 @@ class ChargeAgent():
                 # also write milage if available
                 self.updateMileage()
 
-    def __onPlugConnectionStateChange(self, element, flags):
+                self.session.commit()
+
+    def __onPlugConnectionStateChange(self, element, flags):  # noqa: C901
         plugStatus = self.vehicle.weConnectVehicle.domains['charging']['plugStatus']
+
+        if self.chargingSession is not None:
+            try:
+                self.session.refresh(self.chargingSession)
+            except ObjectDeletedError:
+                LOG.warning('Open charging session was deleted')
+                self.previousChargingSession = None
+                chargingSession = self.session.query(ChargingSession).filter(ChargingSession.vehicle == self.vehicle) \
+                    .order_by(ChargingSession.started.desc()).first()
+                if chargingSession is not None and not chargingSession.isClosed():
+                    self.chargingSession = chargingSession
+                else:
+                    self.chargingSession = None
+
         if element.value == PlugStatus.PlugConnectionState.CONNECTED:
             if self.chargingSession is None or self.chargingSession.isClosed():
                 self.previousChargingSession = self.chargingSession
@@ -171,6 +223,8 @@ class ChargeAgent():
             self.updatePosition()
             # also write milage if available
             self.updateMileage()
+
+            self.session.commit()
         elif element.value == PlugStatus.PlugConnectionState.DISCONNECTED:
             if self.chargingSession is not None and self.chargingSession.isConnectedState():
                 self.chargingSession.disconnected = plugStatus.carCapturedTimestamp.value
@@ -179,20 +233,45 @@ class ChargeAgent():
             # also write milage if available
             self.updateMileage()
 
-    def __onPlugLockStateChange(self, element, flags):
+            self.session.commit()
+
+    def __onPlugLockStateChange(self, element, flags):  # noqa: C901
         plugStatus = self.vehicle.weConnectVehicle.domains['charging']['plugStatus']
+
+        if self.chargingSession is not None:
+            try:
+                self.session.refresh(self.chargingSession)
+            except ObjectDeletedError:
+                LOG.warning('Open charging session was deleted')
+                self.previousChargingSession = None
+                chargingSession = self.session.query(ChargingSession).filter(ChargingSession.vehicle == self.vehicle) \
+                    .order_by(ChargingSession.started.desc()).first()
+                if chargingSession is not None and not chargingSession.isClosed():
+                    self.chargingSession = chargingSession
+                else:
+                    self.chargingSession = None
+
         if element.value == PlugStatus.PlugLockState.LOCKED:
             if self.chargingSession is None or self.chargingSession.isClosed():
-                self.previousChargingSession = self.chargingSession
-                self.chargingSession = ChargingSession(vehicle=self.vehicle)
-                with self.session.begin_nested():
-                    self.session.add(self.chargingSession)
+                # In case this was an interrupted charging session (interrupt no longer than 24hours), continue by erasing end time
+                if self.chargingSession is not None and not self.chargingSession.wasDisconnected() \
+                        and self.chargingSession.ended > (plugStatus.carCapturedTimestamp.value - timedelta(hours=24)):
+                    self.chargingSession.ended = None
+                    self.chargingSession.endSOC_pct = None
+                else:
+                    self.previousChargingSession = self.chargingSession
+                    self.chargingSession = ChargingSession(vehicle=self.vehicle)
+                    with self.session.begin_nested():
+                        self.session.add(self.chargingSession)
+                    self.session.commit()
             if self.chargingSession.locked is None:
                 self.chargingSession.locked = plugStatus.carCapturedTimestamp.value
             # also write position if available
             self.updatePosition()
             # also write milage if available
             self.updateMileage()
+
+            self.session.commit()
         elif element.value == PlugStatus.PlugLockState.UNLOCKED:
             if self.chargingSession is not None and self.chargingSession.isLockedState():
                 self.chargingSession.unlocked = plugStatus.carCapturedTimestamp.value
@@ -201,11 +280,28 @@ class ChargeAgent():
             # also write milage if available
             self.updateMileage()
 
+            self.session.commit()
+
     def __onChargePowerChange(self, element, flags):
+        if self.chargingSession is not None:
+            try:
+                self.session.refresh(self.chargingSession)
+            except ObjectDeletedError:
+                LOG.warning('Open charging session was deleted')
+                self.previousChargingSession = None
+                chargingSession = self.session.query(ChargingSession).filter(ChargingSession.vehicle == self.vehicle) \
+                    .order_by(ChargingSession.started.desc()).first()
+                if chargingSession is not None and not chargingSession.isClosed():
+                    self.chargingSession = chargingSession
+                else:
+                    self.chargingSession = None
+
         if self.chargingSession is not None and self.chargingSession.isChargingState()\
                 and (self.chargingSession.maximumChargePower_kW is None or element.value > self.chargingSession.maximumChargePower_kW):
             self.chargingSession.maximumChargePower_kW = element.value
 
+            self.session.commit()
+
     def updatePosition(self):
         if Privacy.NO_LOCATIONS not in self.privacy:
             if self.vehicle.weConnectVehicle.statusExists('parking', 'parkingPosition'):
