@@ -4,6 +4,7 @@ from datetime import datetime, timezone, timedelta
 
 from sqlalchemy import and_
 from sqlalchemy.exc import IntegrityError
+from sqlalchemy.orm.exc import ObjectDeletedError
 
 from vwsfriend.model.trip import Trip
 from vwsfriend.util.location_util import locationFromLatLonWithGeofence
@@ -41,6 +42,7 @@ class TripAgent():
                 if Privacy.NO_LOCATIONS not in self.privacy:
                     self.lastParkingPositionLatitude = self.trip.destination_position_latitude
                     self.lastParkingPositionLongitude = self.trip.destination_position_longitude
+                self.session.commit()
             else:
                 LOG.info(f'Vehicle {self.vehicle.vin} has still an open trip during startup, closing it now')
             self.trip = None
@@ -106,7 +108,14 @@ class TripAgent():
                 self.vehicle.weConnectVehicle.domains.removeObserver(self.__onStatusesChange)
                 self.__onCarCapturedTimestampEnabled(element, flags)
 
-    def __onCarCapturedTimestampDisabled(self, element: AddressableAttribute, flags):
+    def __onCarCapturedTimestampDisabled(self, element: AddressableAttribute, flags):  # noqa: C901
+        if self.trip is not None:
+            try:
+                self.session.refresh(self.trip)
+            except ObjectDeletedError:
+                LOG.warning('Last trip entry was deleted')
+                self.trip = None
+
         if self.mode == TripAgent.Mode.PARKING_POSITION:
             if element.parent.error.enabled:
                 LOG.debug(f'Vehicle {self.vehicle.vin} removed a parkingPosition but there was an error set')
@@ -150,6 +159,13 @@ class TripAgent():
                 self.lastParkingPositionLongitude = parkingPosition.longitude.value
 
     def __onCarCapturedTimestampEnabled(self, element, flags):  # noqa: C901
+        if self.trip is not None:
+            try:
+                self.session.refresh(self.trip)
+            except ObjectDeletedError:
+                LOG.warning('Last trip entry was deleted')
+                self.trip = None
+
         if self.mode == TripAgent.Mode.PARKING_POSITION:
             parkingPosition = self.vehicle.weConnectVehicle.domains['parking']['parkingPosition']
             if parkingPosition.carCapturedTimestamp.enabled and parkingPosition.carCapturedTimestamp.value is not None:
@@ -176,6 +192,7 @@ class TripAgent():
                             if odometerMeasurement.odometer.enabled and odometerMeasurement.odometer is not None:
                                 self.trip.end_mileage_km = odometerMeasurement.odometer.value
 
+                        self.session.commit()
                         self.trip = None
 
                         LOG.info(f'Vehicle {self.vehicle.vin} ended a trip')
@@ -190,6 +207,13 @@ class TripAgent():
                     LOG.info(f'Vehicle {self.vehicle.vin} provides a parking position, but no trip was started (this is ok during startup)')
 
     def __onIsActiveChanged(self, element, flags):  # noqa: C901
+        if self.trip is not None:
+            try:
+                self.session.refresh(self.trip)
+            except ObjectDeletedError:
+                LOG.warning('Last trip entry was deleted')
+                self.trip = None
+
         if self.mode == TripAgent.Mode.READINESS_STATUS:
             if self.vehicle.weConnectVehicle.statusExists('charging', 'plugStatus'):
                 plugStatus = self.vehicle.weConnectVehicle.domains['charging']['plugStatus']
@@ -221,6 +245,7 @@ class TripAgent():
                         if odometerMeasurement.odometer.enabled and odometerMeasurement.odometer is not None:
                             self.trip.end_mileage_km = odometerMeasurement.odometer.value
 
+                    self.session.commit()
                     self.trip = None
 
                     LOG.info(f'Vehicle {self.vehicle.vin} ended a trip')
@@ -229,6 +254,13 @@ class TripAgent():
                         LOG.info(f'Vehicle {self.vehicle.vin} reports to be inactive, but no trip was started (this is ok during startup)')
 
     def __onPlugConnectionStateChanged(self, element, flags):  # noqa: C901
+        if self.trip is not None:
+            try:
+                self.session.refresh(self.trip)
+            except ObjectDeletedError:
+                LOG.warning('Last trip entry was deleted')
+                self.trip = None
+
         plugStatus = self.vehicle.weConnectVehicle.domains['charging']['plugStatus']
         if element.value == PlugStatus.PlugConnectionState.CONNECTED:
             if self.trip is not None:
@@ -242,6 +274,7 @@ class TripAgent():
                     if odometerMeasurement.odometer.enabled and odometerMeasurement.odometer is not None:
                         self.trip.end_mileage_km = odometerMeasurement.odometer.value
 
+                self.session.commit()
                 self.trip = None
 
                 LOG.info(f'Vehicle {self.vehicle.vin} ended a trip (car was connected to charger)')
