@@ -16,3 +16,5 @@ from .settings import Settings
 from .weconnect_error import WeConnectError
 from .weconnect_responsetime import WeConnectResponsetime
 from .tag import Tag
+from .warning_light import WarningLight
+from .maintenance import Maintenance
