@@ -83,8 +83,10 @@ class GeofenceEditForm(FlaskForm):
 class TripEditForm(FlaskForm):
     id = HiddenField('id', validators=[Optional()])
     vehicle_vin = HiddenField('id', validators=[DataRequired()])
-    startDate = DateTimeLocalField('Start Date and Time (UTC)', validators=[DataRequired()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    endDate = DateTimeLocalField('End Date and Time (UTC)', validators=[DataRequired()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
+    startDate = DateTimeLocalField('Start Date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                   render_kw={"step": "1"})
+    endDate = DateTimeLocalField('End Date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                 render_kw={"step": "1"})
     start_position_latitude = DecimalField('Start Position Latitude', places=10, validators=[Optional(), NumberRange(min=-90, max=90)])
     start_position_longitude = DecimalField('Start Position Longitude', places=10, validators=[Optional(), NumberRange(min=-180, max=180)])
     start_mileage_km = IntegerField('Start Mileage in km', validators=[Optional(), NumberRange(min=0)])
@@ -100,12 +102,18 @@ class TripEditForm(FlaskForm):
 class ChargingSessionEditForm(FlaskForm):
     id = HiddenField('id', validators=[Optional()])
     vehicle_vin = HiddenField('id', validators=[DataRequired()])
-    connected = DateTimeLocalField('Plug Connection Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    locked = DateTimeLocalField('Plug Locked Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    started = DateTimeLocalField('Charging Start Date and Time (UTC)', validators=[DataRequired()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    ended = DateTimeLocalField('Charging End Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    unlocked = DateTimeLocalField('Plug Unlocked Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    disconnected = DateTimeLocalField('Plug Disconnect Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
+    connected = DateTimeLocalField('Plug Connection Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                   render_kw={"step": "1"})
+    locked = DateTimeLocalField('Plug Locked Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                render_kw={"step": "1"})
+    started = DateTimeLocalField('Charging Start Date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                 render_kw={"step": "1"})
+    ended = DateTimeLocalField('Charging End Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                               render_kw={"step": "1"})
+    unlocked = DateTimeLocalField('Plug Unlocked Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                  render_kw={"step": "1"})
+    disconnected = DateTimeLocalField('Plug Disconnect Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                                      render_kw={"step": "1"})
     # maxChargeCurrentACSetting
     targetSOCSetting_pct = IntegerField('Target SoC Setting', validators=[Optional(), NumberRange(min=0, max=100)])
     maximumChargePower_kW = DecimalField('Maximum Power during session', places=4, validators=[Optional(), NumberRange(min=0)])
@@ -128,7 +136,7 @@ class ChargingSessionEditForm(FlaskForm):
 class RefuelSessionEditForm(FlaskForm):
     id = HiddenField('id', validators=[Optional()])
     vehicle_vin = HiddenField('id', validators=[DataRequired()])
-    date = DateTimeLocalField('Date and Time (UTC)', validators=[Optional()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
+    date = DateTimeLocalField('Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'], render_kw={"step": "1"})
     startSOC_pct = IntegerField('SoC at start', validators=[Optional(), NumberRange(min=0, max=100)])
     endSOC_pct = IntegerField('SoC at end', validators=[Optional(), NumberRange(min=0, max=100)])
     mileage_km = IntegerField('Mileage in km when charging', validators=[Optional(), NumberRange(min=0)])
@@ -146,8 +154,9 @@ class RefuelSessionEditForm(FlaskForm):
 class JourneyEditForm(FlaskForm):
     id = HiddenField('id', validators=[Optional()])
     vehicle_vin = HiddenField('id', validators=[DataRequired()])
-    start = DateTimeLocalField('Start date and Time (UTC)', validators=[DataRequired()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
-    end = DateTimeLocalField('End date and Time (UTC)', validators=[DataRequired()], format='%Y-%m-%dT%H:%M:%S', render_kw={"step": "1"})
+    start = DateTimeLocalField('Start date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+                               render_kw={"step": "1"})
+    end = DateTimeLocalField('End date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'], render_kw={"step": "1"})
     title = StringField('Title', validators=[DataRequired()])
     description = StringField('Description', validators=[DataRequired()])
     tags = SelectMultipleField('Tags', validators=[Optional()])
@@ -247,7 +256,7 @@ def settingsEdit():
 @bp.route('/trips/list', methods=['GET'])  # noqa: C901
 @login_required
 def tripList():
-    trips = current_app.db.session.query(Trip).all()
+    trips = current_app.db.session.query(Trip).order_by(Trip.startDate.desc()).all()
     return render_template('database/trip_list.html', current_app=current_app, trips=trips or [])
 
 
@@ -393,7 +402,8 @@ def tripEdit():  # noqa: C901
 @bp.route('/charging-session/list', methods=['GET'])  # noqa: C901
 @login_required
 def chargingSessionList():
-    sessions = current_app.db.session.query(ChargingSession).all()
+    sessions = current_app.db.session.query(ChargingSession).order_by(ChargingSession.started.desc(), ChargingSession.locked.desc(),
+                                                                      ChargingSession.connected.desc()).all()
     return render_template('database/charging_session_list.html', current_app=current_app, sessions=sessions or [])
 
 
@@ -637,7 +647,7 @@ def chargingSessionEdit():  # noqa: C901
 @bp.route('/refuel-session/list', methods=['GET'])  # noqa: C901
 @login_required
 def refuelSessionList():
-    sessions = current_app.db.session.query(RefuelSession).all()
+    sessions = current_app.db.session.query(RefuelSession).order_by(RefuelSession.date.desc()).all()
     return render_template('database/refuel_session_list.html', current_app=current_app, sessions=sessions or [])
 
 
@@ -766,7 +776,7 @@ def refuelSessionEdit():  # noqa: C901
 @bp.route('/journey/list', methods=['GET'])  # noqa: C901
 @login_required
 def journeyList():
-    journeys = current_app.db.session.query(Journey).all()
+    journeys = current_app.db.session.query(Journey).order_by(Journey.start.desc()).all()
     return render_template('database/journey_list.html', current_app=current_app, journeys=journeys or [])
 
 
@@ -878,7 +888,7 @@ def journeyEdit():  # noqa: C901
 @bp.route('/operator/list', methods=['GET'])  # noqa: C901
 @login_required
 def operatorList():
-    operators = current_app.db.session.query(Operator).filter(Operator.custom).all()
+    operators = current_app.db.session.query(Operator).order_by(Operator.id.asc()).filter(Operator.custom).all()
     return render_template('database/operator_list.html', current_app=current_app, operators=operators or [])
 
 
@@ -939,7 +949,7 @@ def operatorEdit():  # noqa: C901
 @bp.route('/tag/list', methods=['GET'])  # noqa: C901
 @login_required
 def tagList():
-    tags = current_app.db.session.query(Tag).all()
+    tags = current_app.db.session.query(Tag).order_by(Tag.name.asc()).all()
     return render_template('database/tag_list.html', current_app=current_app, tags=tags or [])
 
 
@@ -1006,7 +1016,7 @@ def tagEdit():  # noqa: C901
 @bp.route('/charger/list', methods=['GET'])  # noqa: C901
 @login_required
 def chargerList():
-    chargers = current_app.db.session.query(Charger).filter(Charger.custom).all()
+    chargers = current_app.db.session.query(Charger).order_by(Charger.id.asc()).filter(Charger.custom).all()
     return render_template('database/charger_list.html', current_app=current_app, chargers=chargers or [])
 
 
@@ -1105,7 +1115,7 @@ def chargerEdit():  # noqa: C901
 @bp.route('/geofence/list', methods=['GET'])  # noqa: C901
 @login_required
 def geofenceList():
-    geofences = current_app.db.session.query(Geofence).all()
+    geofences = current_app.db.session.query(Geofence).order_by(Geofence.id.asc()).all()
     return render_template('database/geofence_list.html', current_app=current_app, geofences=geofences or [])
 
 
