@@ -27,6 +27,8 @@ import vwsfriend.ui.status as status
 import vwsfriend.ui.settings as settings
 import vwsfriend.ui.database as database
 
+from vwsfriend.ui.cache import cache
+
 from vwsfriend.__version import __version__ as __vwsfriend_version__
 from weconnect.__version import __version__ as __weconnect_version__
 
@@ -54,6 +56,8 @@ class VWsFriendUI:
         )
         csrf.init_app(self.app)
 
+        cache.init_app(self.app)
+
         loginManager = flask_login.LoginManager()
         loginManager.init_app(self.app)
         loginManager.login_view = "login"
