@@ -78,7 +78,7 @@ def main():  # noqa: C901 pylint: disable=too-many-branches, too-many-statements
                                 ' Netrc is only used when username and password are not provided  as arguments',
                                 default=None, required=False)
     weConnectGroup.add_argument('-i', '--interval', help='Query interval in seconds',
-                                type=NumberRangeArgument(imin=180), required=False, default=300)
+                                type=NumberRangeArgument(imin=120), required=False, default=180)
     defaultTemp = os.path.join(tempfile.gettempdir(), 'weconnect.token')
     weConnectGroup.add_argument('--tokenfile', help=f'file to store token (default: {defaultTemp})', default=defaultTemp)
     weConnectGroup.add_argument('--no-token-storage', dest='noTokenStorage', help='Do not store token on filesystem (this'
@@ -98,6 +98,10 @@ def main():  # noqa: C901 pylint: disable=too-many-branches, too-many-statements
 
     homekitGroup = parser.add_argument_group('Homekit')
     homekitGroup.add_argument('--with-homekit', dest='withHomekit', help='Provide Apple Homekit functionality', action='store_true')
+    homekitGroup.add_argument('--homekit-address', dest='homekitAddress', type=str, help='IP address used to listen on for Apple Homekit functionality',
+                              default=None)
+    homekitGroup.add_argument('--homekit-port', dest='homekitPort', help='Port used to listen on for Apple Homekit functionality', type=int,
+                              choices=range(1, 65535), metavar="[1-65535]", required=False, default=51234)
 
     loggingGroup = parser.add_argument_group('Logging')
     loggingGroup.add_argument('-v', '--verbose', action="append_const", help='Logging level (verbosity)', const=-1,)
@@ -221,8 +225,8 @@ def main():  # noqa: C901 pylint: disable=too-many-branches, too-many-statements
         driver = None
         if args.withHomekit:
             LOG.info('Starting up Homekit')
-            # Start the accessory on port 51826
-            driver = AccessoryDriver(pincode=None, persist_file=f'{args.configDir}/accessory.state')
+            # Start the accessory on port 51234
+            driver = AccessoryDriver(address=args.homekitAddress, port=args.homekitPort, pincode=None, persist_file=f'{args.configDir}/accessory.state')
 
             for characteristicKey, characteristic in CUSTOM_CHARACTERISTICS.items():
                 driver.loader.char_types[characteristicKey] = characteristic
@@ -244,6 +248,8 @@ def main():  # noqa: C901 pylint: disable=too-many-branches, too-many-statements
 
         if args.demo is not None:
             utcDemoStart = datetime.utcnow().replace(tzinfo=timezone.utc, microsecond=0)
+            # In demomode do not fix anything.
+            weConnect.fixAPI = False
             for file in sorted(os.listdir(args.demo)):
                 fileNameRegex = r'(?P<number>\d+)_(?P<delay>\d+)s(_(?P<stage>[^\.]+))?.cache.json'
                 match = re.search(fileNameRegex, file)
